require 'pathname'
require(Pathname.new(__FILE__).parent + 'lib/common.rb')


describe 'Normal Code Block:' do
	before(:each) do
		@bf = BlueFeather::Parser.new
		@html = @bf.parse_text(@src)
		@doc = Hpricot(@html)
	end


	describe '> ol:' do
		before(:all) do
			@src = "    1. item-1\n    2. item-2\n    3. item-3\n"
		end
		
		specify 'basic' do
			@doc.should have_elements(1, 'pre code')
			@doc.should_not have_element('ol')
		end
	end
end

describe 'Fenced Code Block:' do
	before(:each) do
		@bf = BlueFeather::Parser.new
		@html = @bf.parse_text(@src)
		@doc = Hpricot(@html)
	end


	describe 'Basic:' do
		share_as :Examples do
			specify 'overview' do
				@doc.should have_elements(1, 'pre code')
				@doc.should_not have_element('p')
			end
			
			specify 'body' do
				@doc.at('pre code').inner_text.should == "Fenced Code\nBlock\n"
			end
		end
		
		share_as :NegativeExamples do
			specify 'overview' do
				@doc.should_not have_elements(1, 'pre code')
				@doc.should have_elements(1, 'p')
			end
		end

	
		describe 'Standard:' do
			include Examples
			before(:all) do
				@src = "~~~\nFenced Code\nBlock\n~~~"
			end
		end
		
		describe 'Many Symbols:' do
			include Examples
			before(:all) do
				@src = "~~~~~~\nFenced Code\nBlock\n~~~~~~"
			end
		end
		
		describe 'Original Code Block:' do
			include Examples
			before(:all) do
				@src = "    Fenced Code\n    Block"
			end
		end
		
		describe 'Bad (wrong number of symbols):' do
			include NegativeExamples
			before(:all) do
				@src = "~~~~~~\nFenced Code\nBlock\n~~~"
			end
		end

		describe 'Bad (symbols is not on line-head.):' do
			include NegativeExamples
			before(:all) do
				@src = " ~~~\nFenced Code\nBlock\n ~~~"
			end
		end

		
	end

end
