require 'pathname'
require(Pathname.new(__FILE__).parent + 'lib/common.rb')


describe 'TOC:' do
	before(:each) do
		@bf = BlueFeather::Parser.new
		@html = @bf.parse_text(@src)
		@doc = Hpricot(@html)
	end


	describe 'basic:' do
		before(:all) do
			@src = <<-MARKDOWN
{toc}

# h1 #
## h2a ##
## h2b ##
### h3a ###
### h3b ###
### h3c ###
## h2c ##
			MARKDOWN
		end
		
		specify 'overview' do
			@doc.should have_element('ul')
			@doc.should have_elements(1, 'h1')
			@doc.should have_elements(3, 'h2')
			@doc.should have_elements(3, 'h3')
		end
		
		specify 'list structure' do
			toc = @doc.at('ul')
			toc['class'] = 'toc'
			
			@doc.should have_elements(3, 'ul.toc > li')
			@doc.should have_elements(1, 'ul.toc > li > ul')
			@doc.should have_elements(3, 'ul.toc > li > ul > li')
		end
		
		specify 'list content' do
			toc = @doc.at('ul')
			toc['class'] = 'toc'
			
			items1 = @doc.search('ul.toc > li')
			items1[0].inner_text.should == 'h2a'
			items1[2].inner_text.should == 'h2c'

			items2 = @doc.search('ul.toc > li > ul > li')
			items2[0].inner_text.should == 'h3a'
			items2[1].inner_text.should == 'h3b'
			items2[2].inner_text.should == 'h3c'
		end

	end

	
	


end